@@ -1,5 +1,5 @@
 /*
- * Copyright © 2006 Sun Microsystems, Inc.  All rights reserved.
+ * Copyright (c) 2006, Oracle and/or its affiliates. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -48,58 +48,61 @@
 #include "compint.h"
 #include "xace.h"
 
+#ifdef PANORAMIX
+#include "panoramiXsrv.h"
+#endif
+
 /* 
  * Delete the given overlay client list element from its screen list.
  */
 void
-compFreeOverlayClient (CompOverlayClientPtr pOcToDel)
+compFreeOverlayClient(CompOverlayClientPtr pOcToDel)
 {
-    ScreenPtr		    pScreen = pOcToDel->pScreen;
-    CompScreenPtr	    cs = GetCompScreen (pScreen);
-    CompOverlayClientPtr    *pPrev, pOc;
+    ScreenPtr pScreen = pOcToDel->pScreen;
+    CompScreenPtr cs = GetCompScreen(pScreen);
+    CompOverlayClientPtr *pPrev, pOc;
 
-    for (pPrev = &cs->pOverlayClients; (pOc = *pPrev); pPrev = &pOc->pNext)
-    {
-	if (pOc == pOcToDel) {
-	    *pPrev = pOc->pNext;
-	    free(pOc);
-	    break;
-	}
+    for (pPrev = &cs->pOverlayClients; (pOc = *pPrev); pPrev = &pOc->pNext) {
+        if (pOc == pOcToDel) {
+            *pPrev = pOc->pNext;
+            free(pOc);
+            break;
+        }
     }
-    
+
     /* Destroy overlay window when there are no more clients using it */
     if (cs->pOverlayClients == NULL)
-	compDestroyOverlayWindow (pScreen);
+        compDestroyOverlayWindow(pScreen);
 }
 
 /*
  * Return the client's first overlay client rec from the given screen
  */
 CompOverlayClientPtr
-compFindOverlayClient (ScreenPtr pScreen, ClientPtr pClient)
+compFindOverlayClient(ScreenPtr pScreen, ClientPtr pClient)
 {
-    CompScreenPtr	    cs = GetCompScreen(pScreen);
-    CompOverlayClientPtr    pOc;
+    CompScreenPtr cs = GetCompScreen(pScreen);
+    CompOverlayClientPtr pOc;
 
     for (pOc = cs->pOverlayClients; pOc != NULL; pOc = pOc->pNext)
-	if (pOc->pClient == pClient)
-	    return pOc;
+        if (pOc->pClient == pClient)
+            return pOc;
 
-    return NULL;           
+    return NULL;
 }
 
 /*
  * Create an overlay client object for the given client
  */
 CompOverlayClientPtr
-compCreateOverlayClient (ScreenPtr pScreen, ClientPtr pClient)
+compCreateOverlayClient(ScreenPtr pScreen, ClientPtr pClient)
 {
-    CompScreenPtr    cs = GetCompScreen(pScreen);
+    CompScreenPtr cs = GetCompScreen(pScreen);
     CompOverlayClientPtr pOc;
 
     pOc = (CompOverlayClientPtr) malloc(sizeof(CompOverlayClientRec));
     if (pOc == NULL)
-	return NULL;
+        return NULL;
 
     pOc->pClient = pClient;
     pOc->pScreen = pScreen;
@@ -111,8 +114,8 @@ compCreateOverlayClient (ScreenPtr pScreen, ClientPtr pClient)
      * Create a resource for this element so it can be deleted
      * when the client goes away.
      */
-    if (!AddResource (pOc->resource, CompositeClientOverlayType, (pointer) pOc))
-	return NULL;
+    if (!AddResource(pOc->resource, CompositeClientOverlayType, (pointer) pOc))
+        return NULL;
 
     return pOc;
 }
@@ -121,25 +124,33 @@ compCreateOverlayClient (ScreenPtr pScreen, ClientPtr pClient)
  * Create the overlay window and map it
  */
 Bool
-compCreateOverlayWindow (ScreenPtr pScreen)
+compCreateOverlayWindow(ScreenPtr pScreen)
 {
-    CompScreenPtr   cs = GetCompScreen(pScreen);
-    WindowPtr	    pRoot = pScreen->root;
-    WindowPtr	    pWin;
-    XID		    attrs[] = { None, TRUE }; /* backPixmap, overrideRedirect */
-    int		    result;
+    CompScreenPtr cs = GetCompScreen(pScreen);
+    WindowPtr pRoot = pScreen->root;
+    WindowPtr pWin;
+    XID attrs[] = { None, TRUE };       /* backPixmap, overrideRedirect */
+    int result;
+    int w = pScreen->width;
+    int h = pScreen->height;
 
-    pWin = cs->pOverlayWin = 
-	CreateWindow (cs->overlayWid, pRoot,
-		      0, 0, pScreen->width, pScreen->height, 0, 
-		      InputOutput, CWBackPixmap | CWOverrideRedirect, &attrs[0],
-		      pRoot->drawable.depth, 
-		      serverClient, pScreen->rootVisual, &result);
+#ifdef PANORAMIX
+    if (!noPanoramiXExtension) {
+        w = PanoramiXPixWidth;
+        h = PanoramiXPixHeight;
+    }
+#endif
+
+    pWin = cs->pOverlayWin =
+        CreateWindow(cs->overlayWid, pRoot, 0, 0, w, h, 0,
+                     InputOutput, CWBackPixmap | CWOverrideRedirect, &attrs[0],
+                     pRoot->drawable.depth,
+                     serverClient, pScreen->rootVisual, &result);
     if (pWin == NULL)
-	return FALSE;
+        return FALSE;
 
-    if (!AddResource(pWin->drawable.id, RT_WINDOW, (pointer)pWin))
-	return FALSE;
+    if (!AddResource(pWin->drawable.id, RT_WINDOW, (pointer) pWin))
+        return FALSE;
 
     MapWindow(pWin, serverClient);
 
@@ -150,11 +161,10 @@ compCreateOverlayWindow (ScreenPtr pScreen)
  * Destroy the overlay window
  */
 void
-compDestroyOverlayWindow (ScreenPtr pScreen)
+compDestroyOverlayWindow(ScreenPtr pScreen)
 {
     CompScreenPtr cs = GetCompScreen(pScreen);
 
     cs->pOverlayWin = NullWindow;
-    FreeResource (cs->overlayWid, RT_NONE);
+    FreeResource(cs->overlayWid, RT_NONE);
 }
-
