@@ -7,11 +7,11 @@
 	<key>CFBundleExecutable</key>
 		<string>X11</string>
 	<key>CFBundleGetInfoString</key>
-		<string>APPLE_APPLICATION_NAME</string>
+		<string>BUNDLE_ID_PREFIX.X11</string>
 	<key>CFBundleIconFile</key>
 		<string>X11.icns</string>
 	<key>CFBundleIdentifier</key>
-		<string>APPLE_APPLICATION_ID</string>
+		<string>BUNDLE_ID_PREFIX.X11</string>
 	<key>CFBundleInfoDictionaryVersion</key>
 		<string>6.0</string>
 	<key>CFBundleName</key>
@@ -19,17 +19,27 @@
 	<key>CFBundlePackageType</key>
 		<string>APPL</string>
 	<key>CFBundleShortVersionString</key>
-		<string>2.3.2</string>
+		<string>2.7.3</string>
 	<key>CFBundleVersion</key>
-		<string>2.3.2</string>
+		<string>2.7.3</string>
 	<key>CFBundleSignature</key>
 		<string>x11a</string>
 	<key>CSResourcesFileMapped</key>
 		<true/>
+#ifdef XQUARTZ_SPARKLE
+	<key>SUEnableAutomaticChecks</key>
+		<true/>
+	<key>SUPublicDSAKeyFile</key>
+		<string>sparkle.pem</string>
+        <key>SUFeedURL</key>
+                <string>http://xquartz.macosforge.org/downloads/sparkle/release.xml</string>
+#endif
+	<key>LSApplicationCategoryType</key>
+		<string>public.app-category.utilities</string>
 	<key>NSHumanReadableCopyright</key>
-		<string>Copyright © 2003-2009, Apple Inc.
-Copyright © 2003, XFree86 Project, Inc.
-Copyright © 2003-2009, X.org Foundation, Inc.
+		<string>© 2003-2012 Apple Inc.
+© 2003 XFree86 Project, Inc.
+© 2003-2012 X.org Foundation, Inc.
 </string>
 	<key>NSMainNibFile</key>
 		<string>main</string>
