@@ -6,6 +6,6 @@ extern int noPseudoramiXExtension;
 
 void
 PseudoramiXAddScreen(int x, int y, int w, int h);
-void PseudoramiXExtensionInit(int argc, char *argv[]);
+void PseudoramiXExtensionInit(void);
 void
 PseudoramiXResetScreens(void);
